Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrInvalidSignature = errors.New("invalid master boot record signature")
Functions ¶
This section is empty.
Types ¶
type PartitionEntry ¶
type PartitionEntry struct {
BootIndicator uint8
StartAddress Address
Type uint8
EndAddress Address
StartingLBA uint32
NumberOfSectors uint32
}
PartitionEntry corresponds to a partition entry from a MBR.
type Record ¶
type Record struct {
BootstrapCode [440]byte
UniqueSignature uint32
Partitions [4]PartitionEntry
}
Record corresponds to a MBR.
func ReadRecord ¶
ReadRecord reads a MBR from r. It returns ErrInvalidSignature if the MBR has an invalid signature.
func (*Record) IsProtectiveMBR ¶ added in v1.5.0
IsProtectiveMBR indicates whether this is a PMBR, which is present in the first sector of a GPT volume.
Click to show internal directories.
Click to hide internal directories.